@@ -21,8 +21,7 @@
  * A collection of functions for changing options in gpg.conf.
  */
 
-#ifndef __SEAHORSE_GPG_OPTIONS_H__
-#define __SEAHORSE_GPG_OPTIONS_H__
+#pragma once
 
 #include <glib.h>
 
@@ -30,14 +29,12 @@ const gchar * seahorse_gpg_homedir (void);
 
 gboolean seahorse_gpg_options_find(const gchar* option, 
                                 gchar** value, GError** err);
-                                
+
 gboolean seahorse_gpg_options_find_vals(const gchar* options[], 
                                 gchar* values[], GError** err);
 
 gboolean seahorse_gpg_options_change(const gchar* option, 
                                 const gchar* value, GError** err);
-                                
+
 gboolean seahorse_gpg_options_change_vals(const gchar* options[], 
                                 gchar* values[], GError** err);
-
-#endif /* __SEAHORSE_WIDGET_H__ */
