@@ -151,7 +151,7 @@ seahorse_keyserver_results_row_new (GObject *item)
     gtk_style_context_add_class (gtk_widget_get_style_context (import_button),
                                  "flat");
     if (item_exportable)
-        gtk_widget_set_tooltip_text (import_button, _("Import"));
+        gtk_widget_set_tooltip_text (import_button, _("_Import"));
     else
         gtk_widget_set_tooltip_text (import_button, _("Can’t import key"));
     gtk_grid_attach (GTK_GRID (grid), g_steal_pointer (&import_button), 1, 0, 1, 1);
@@ -242,7 +242,7 @@ seahorse_keyserver_results_constructed (GObject *obj)
         title = g_strdup_printf (_("Remote keys containing “%s”"), self->search_string);
     }
 
-    gtk_window_set_default_geometry (window, 640, 476);
+    gtk_window_set_default_size (window, 640, 476);
     gtk_window_set_title (window, title);
     gtk_widget_set_visible (GTK_WIDGET (window), TRUE);
 
@@ -347,9 +347,10 @@ static void
 on_search_completed (GObject *source, GAsyncResult *result, gpointer user_data)
 {
     SeahorseKeyserverResults *self = SEAHORSE_KEYSERVER_RESULTS (user_data);
+    SeahorsePgpBackend *backend = seahorse_pgp_backend_get ();
     g_autoptr(GError) error = NULL;
 
-    seahorse_pgp_backend_search_remote_finish (NULL, result, &error);
+    seahorse_pgp_backend_search_remote_finish (backend, result, &error);
     if (error != NULL) {
         g_dbus_error_strip_remote_error (error);
         seahorse_util_show_error (GTK_WIDGET (self),
@@ -385,7 +386,8 @@ seahorse_keyserver_results_show (const gchar* search_text, GtkWindow *parent)
 
     cancellable = g_cancellable_new ();
 
-    seahorse_pgp_backend_search_remote_async (NULL, search_text,
+    seahorse_pgp_backend_search_remote_async (seahorse_pgp_backend_get (),
+                                              search_text,
                                               self->collection,
                                               cancellable, on_search_completed,
                                               g_object_ref (self));
