@@ -25,10 +25,9 @@
 #include "seahorse-pgp-backend.h"
 #include "seahorse-transfer.h"
 
-#include "libseahorse/seahorse-object.h"
-#include "libseahorse/seahorse-prefs.h"
+#include "seahorse-common.h"
+
 #include "libseahorse/seahorse-progress.h"
-#include "libseahorse/seahorse-servers.h"
 #include "libseahorse/seahorse-util.h"
 #include "libseahorse/seahorse-widget.h"
 
@@ -50,10 +49,9 @@ on_transfer_upload_complete (GObject *object,
 	gchar *publish_to;
 
 	if (!seahorse_pgp_backend_transfer_finish (SEAHORSE_PGP_BACKEND (object), result, &error)) {
-		publish_to = g_settings_get_string (seahorse_application_settings (NULL),
-		                                    "server-publish-to");
+		publish_to = seahorse_app_settings_get_server_publish_to (seahorse_app_settings_instance ());
 		seahorse_util_handle_error (&error, NULL,
-		                            _("Couldn't publish keys to server"), publish_to);
+		                            _("Couldn’t publish keys to server"), publish_to);
 		g_free (publish_to);
 	}
 
@@ -72,7 +70,7 @@ on_transfer_download_complete (GObject *object,
 	if (!seahorse_transfer_finish (result, &error)) {
 		g_object_get (place, "key-server", &keyserver, NULL);
 		seahorse_util_handle_error (&error, NULL,
-		                            _("Couldn't retrieve keys from server: %s"), keyserver);
+		                            _("Couldn’t retrieve keys from server: %s"), keyserver);
 		g_free (keyserver);
 	}
 
@@ -96,7 +94,9 @@ on_sync_ok_clicked (GtkButton *button, SeahorseWidget *swidget)
 G_MODULE_EXPORT void
 on_sync_configure_clicked (GtkButton *button, SeahorseWidget *swidget)
 {
-    seahorse_prefs_show (GTK_WINDOW (seahorse_widget_get_widget (swidget, swidget->name)), "keyserver-tab");
+    SeahorsePrefs *prefs_dialog = seahorse_prefs_new (GTK_WINDOW (seahorse_widget_get_widget (swidget, swidget->name)), "keyserver-tab");
+    gtk_dialog_run (GTK_DIALOG (prefs_dialog));
+    gtk_widget_destroy (GTK_WIDGET (prefs_dialog));
 }
 
 static void
@@ -111,8 +111,7 @@ update_message (SeahorseWidget *swidget)
 	widget2 = seahorse_widget_get_widget (swidget, "sync-message");
 	sync_button = seahorse_widget_get_widget (swidget, "sync-button");
 
-	text = g_settings_get_string (seahorse_application_settings (NULL),
-	                              "server-publish-to");
+	text = seahorse_app_settings_get_server_publish_to (seahorse_app_settings_instance ());
 	if (text && text[0]) {
 		gtk_widget_show (widget);
 		gtk_widget_hide (widget2);
@@ -166,7 +165,7 @@ seahorse_keyserver_sync_show (GList *keys, GtkWindow *parent)
 
     /* The right help message */
     update_message (swidget);
-    g_signal_connect_object (seahorse_application_settings (NULL), "changed::server-publish-to",
+    g_signal_connect_object (seahorse_app_settings_instance (), "changed::server-publish-to",
                              G_CALLBACK (on_settings_publish_to_changed), swidget, 0);
 
     keys = g_list_copy (keys);
@@ -221,8 +220,7 @@ seahorse_keyserver_sync (GList *keys)
 	g_strfreev (keyservers);
 
 	/* Publishing keys online */
-	keyserver = g_settings_get_string (seahorse_application_settings (NULL),
-	                                   "server-publish-to");
+	keyserver = seahorse_app_settings_get_server_publish_to (seahorse_app_settings_instance ());
 	if (keyserver && keyserver[0]) {
 		source = seahorse_pgp_backend_lookup_remote (NULL, keyserver);
 
@@ -236,6 +234,6 @@ seahorse_keyserver_sync (GList *keys)
 
 	g_free (keyserver);
 
-	seahorse_progress_show (cancellable, _("Synchronizing keys..."), FALSE);
+	seahorse_progress_show (cancellable, _("Synchronizing keys…"), FALSE);
 	g_object_unref (cancellable);
 }
