@@ -35,9 +35,9 @@ G_DECLARE_FINAL_TYPE (SeahorseLDAPSource, seahorse_ldap_source,
                       SEAHORSE, LDAP_SOURCE,
                       SeahorseServerSource)
 
-SeahorseLDAPSource*   seahorse_ldap_source_new     (const gchar *uri,
-                                                    const gchar *host);
+SeahorseLDAPSource*   seahorse_ldap_source_new     (const char *uri,
+                                                    const char *host);
 
-gboolean              seahorse_ldap_is_valid_uri   (const gchar *uri);
+gboolean              seahorse_ldap_is_valid_uri   (const char *uri);
 
 #endif /* WITH_LDAP */
