@@ -24,11 +24,14 @@
 #include "config.h"
 
 #include "seahorse-pgp-dialogs.h"
+#include "seahorse-gpgme-add-subkey.h"
 #include "seahorse-gpgme-add-uid.h"
 #include "seahorse-gpgme-dialogs.h"
+#include "seahorse-gpgme-expires-dialog.h"
 #include "seahorse-gpgme-exporter.h"
 #include "seahorse-gpgme-key.h"
 #include "seahorse-gpgme-key-op.h"
+#include "seahorse-gpgme-sign-dialog.h"
 #include "seahorse-pgp-backend.h"
 #include "seahorse-gpg-op.h"
 #include "seahorse-pgp-dialogs.h"
@@ -294,13 +297,17 @@ on_uids_sign (GSimpleAction *action, GVariant *param, gpointer user_data)
 {
     SeahorsePgpKeyProperties *self = SEAHORSE_PGP_KEY_PROPERTIES (user_data);
     SeahorsePgpUid *uid;
+    SeahorseGpgmeSignDialog *dialog;
 
     uid = names_get_selected_uid (self);
-    if (uid != NULL) {
-        g_return_if_fail (SEAHORSE_GPGME_IS_UID (uid));
-        seahorse_gpgme_sign_prompt_uid (SEAHORSE_GPGME_UID (uid),
-                                        GTK_WINDOW (self));
-    }
+    if (uid == NULL)
+        return;
+
+    g_return_if_fail (SEAHORSE_GPGME_IS_UID (uid));
+
+    dialog = seahorse_gpgme_sign_dialog_new (SEAHORSE_OBJECT (uid));
+    gtk_dialog_run (GTK_DIALOG (dialog));
+    gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
 static void
@@ -311,7 +318,7 @@ on_uids_revoke (GSimpleAction *action, GVariant *param, gpointer user_data)
     gint index;
     Glist *keys = NULL;
 
-    skey = SEAHORSE_OBJECT_WIDGET (swidget)->skey;
+    skey = self->key;
     index = names_get_selected_uid (swidget);
 
     if (index >= 1) {
@@ -933,14 +940,47 @@ details_subkey_selected (GtkTreeSelection *selection, SeahorsePgpKeyProperties *
     set_action_enabled (self, "subkeys.delete", subkey != NULL);
 }
 
+static void
+on_add_subkey_completed (GObject *object, GAsyncResult *res, gpointer user_data)
+{
+    SeahorsePgpKeyProperties *self = SEAHORSE_PGP_KEY_PROPERTIES (user_data);
+    g_autoptr(GError) error = NULL;
+
+    if (!seahorse_gpgme_key_op_add_subkey_finish (SEAHORSE_GPGME_KEY (self->key),
+                                                  res, &error)) {
+        seahorse_util_handle_error (&error, self, NULL);
+    }
+}
+
 static void
 on_subkeys_add (GSimpleAction *action, GVariant *param, gpointer user_data)
 {
     SeahorsePgpKeyProperties *self = SEAHORSE_PGP_KEY_PROPERTIES (user_data);
+    SeahorseGpgmeAddSubkey *dialog;
+    int response;
+    SeahorseKeyEncType type;
+    guint length;
+    gulong expires;
 
     g_return_if_fail (SEAHORSE_GPGME_IS_KEY (self->key));
-    seahorse_gpgme_add_subkey_new (SEAHORSE_GPGME_KEY (self->key),
-                                   GTK_WINDOW (self));
+
+    dialog = seahorse_gpgme_add_subkey_new (SEAHORSE_GPGME_KEY (self->key),
+                                            GTK_WINDOW (self));
+
+    response = gtk_dialog_run (GTK_DIALOG (dialog));
+    if (response != GTK_RESPONSE_OK) {
+        gtk_widget_destroy (GTK_WIDGET (dialog));
+        return;
+    }
+
+    length = seahorse_gpgme_add_subkey_get_keysize (dialog);
+    type = seahorse_gpgme_add_subkey_get_active_type (dialog);
+    expires = seahorse_gpgme_add_subkey_get_expires (dialog);
+    seahorse_gpgme_key_op_add_subkey_async (SEAHORSE_GPGME_KEY (self->key),
+                                            type, length, expires, NULL,
+                                            on_add_subkey_completed, self);
+
+    gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
 static void
@@ -992,6 +1032,7 @@ on_subkeys_change_expires (GSimpleAction *action, GVariant *param, gpointer user
     SeahorsePgpKeyProperties *self = SEAHORSE_PGP_KEY_PROPERTIES (user_data);
     SeahorsePgpSubkey *subkey;
     GList *subkeys;
+    GtkDialog *dialog;
 
     subkey = get_selected_subkey (self);
     if (subkey == NULL) {
@@ -1002,9 +1043,13 @@ on_subkeys_change_expires (GSimpleAction *action, GVariant *param, gpointer user
 
     g_return_if_fail (SEAHORSE_GPGME_IS_SUBKEY (subkey));
 
-    if (subkey != NULL)
-        seahorse_gpgme_expires_new (SEAHORSE_GPGME_SUBKEY (subkey),
-                                    GTK_WINDOW (self));
+    if (subkey == NULL)
+        return;
+
+    dialog = seahorse_gpgme_expires_dialog_new (SEAHORSE_GPGME_SUBKEY (subkey),
+                                                GTK_WINDOW (self));
+    gtk_dialog_run (dialog);
+    gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
 static void
@@ -1045,9 +1090,8 @@ on_export_complete (GObject *source, GAsyncResult *result, gpointer user_data)
 }
 
 static void
-on_export_secret (GSimpleAction *action, GVariant *param, gpointer user_data)
+export_key_to_file (SeahorsePgpKeyProperties *self, gboolean secret)
 {
-    SeahorsePgpKeyProperties *self = SEAHORSE_PGP_KEY_PROPERTIES (user_data);
     GList *exporters = NULL;
     GtkWindow *window;
     g_autofree gchar *directory = NULL;
@@ -1055,7 +1099,7 @@ on_export_secret (GSimpleAction *action, GVariant *param, gpointer user_data)
     SeahorseExporter *exporter = NULL;
 
     exporters = g_list_append (exporters,
-                               seahorse_gpgme_exporter_new (G_OBJECT (self->key), TRUE, TRUE));
+                               seahorse_gpgme_exporter_new (G_OBJECT (self->key), TRUE, secret));
 
     window = GTK_WINDOW (self);
     if (seahorse_exportable_prompt (exporters, window, &directory, &file, &exporter)) {
@@ -1067,17 +1111,36 @@ on_export_secret (GSimpleAction *action, GVariant *param, gpointer user_data)
     g_list_free_full (exporters, g_object_unref);
 }
 
+static void
+on_export_secret (GSimpleAction *action, GVariant *param, gpointer user_data)
+{
+    SeahorsePgpKeyProperties *self = SEAHORSE_PGP_KEY_PROPERTIES (user_data);
+
+    export_key_to_file (self, TRUE);
+}
+
+static void
+on_export_public (GSimpleAction *action, GVariant *param, gpointer user_data)
+{
+    SeahorsePgpKeyProperties *self = SEAHORSE_PGP_KEY_PROPERTIES (user_data);
+
+    export_key_to_file (self, FALSE);
+}
+
 static void
 on_change_expires (GSimpleAction *action, GVariant *param, gpointer user_data)
 {
     SeahorsePgpKeyProperties *self = SEAHORSE_PGP_KEY_PROPERTIES (user_data);
     GList *subkeys;
+    GtkDialog *dialog;
 
     subkeys = seahorse_pgp_key_get_subkeys (self->key);
     g_return_if_fail (subkeys);
 
-    seahorse_gpgme_expires_new (SEAHORSE_GPGME_SUBKEY (subkeys->data),
-                                GTK_WINDOW (self));
+    dialog = seahorse_gpgme_expires_dialog_new (SEAHORSE_GPGME_SUBKEY (subkeys->data),
+                                                GTK_WINDOW (self));
+    gtk_dialog_run (dialog);
+    gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
 static void
@@ -1424,9 +1487,14 @@ static void
 on_sign_key (GSimpleAction *action, GVariant *param, gpointer user_data)
 {
     SeahorsePgpKeyProperties *self = SEAHORSE_PGP_KEY_PROPERTIES (user_data);
+    SeahorseGpgmeSignDialog *dialog;
 
     g_return_if_fail (SEAHORSE_GPGME_IS_KEY (self->key));
-    seahorse_gpgme_sign_prompt (SEAHORSE_GPGME_KEY (self->key), GTK_WINDOW (self));
+
+    dialog = seahorse_gpgme_sign_dialog_new (SEAHORSE_OBJECT (self->key));
+
+    gtk_dialog_run (GTK_DIALOG (dialog));
+    gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
 /* When the 'only display trusted' check is checked, hide untrusted rows */
@@ -1578,6 +1646,7 @@ static const GActionEntry PRIVATE_KEY_ACTIONS[] = {
     { "change-password",  on_change_password  },
     { "change-expires",   on_change_expires   },
     { "export-secret",    on_export_secret    },
+    { "export-public",    on_export_public    },
     { "uids.add",           on_uids_add           },
     { "uids.delete",        on_uids_delete        },
     { "uids.make-primary",  on_uids_make_primary  },
